#
# spec file for package wiiuse
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libwiiuse0
Name:           wiiuse
Version:        0.15.6
Release:        1.3
Summary:        Connects with several Nintendo Wii remotes
License:        GPL-3.0-only AND LGPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://github.com/wiiuse/wiiuse
Source0:        https://github.com/wiiuse/wiiuse/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  bluez-devel
BuildRequires:  cmake > 3.6.0
BuildRequires:  dos2unix
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(sdl)

%description
Wiiuse is a library written in C that connects with several Nintendo
Wii remotes.  Supports motion sensing, IR tracking, nunchuk, classic
controller, and the Guitar Hero 3 controller.  Single threaded and
nonblocking makes a light weight and clean API.

%package -n %{libname}
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++

%description  -n %{libname}
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       bluez-devel

%description  devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1

dos2unix CHANGELOG.mkd README.mkd

%build
%cmake
%make_build

%install
%cmake_install

# Docs will be installed by %%doc
rm -rf %{buildroot}%{_datadir}/doc/wiiuse

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license LICENSE
%{_libdir}/*.so.*
%{_libdir}/pkgconfig/wiiuse.pc

%files devel
%doc README.mkd RELEASE.md CHANGELOG.mkd
%{_includedir}/*
%{_libdir}/*.so
%{_bindir}/wiiuseexample
%{_bindir}/wiiuseexample-sdl

%changelog
* Mon Aug 12 2024 ming li <mli@suse.com>
- Update to version 0.15.6
  * Linux - Fixed hang with kernels 6.6.x and newer
  * Corrected historical record about Wiiuse origins
  * Require CMake > 3.6.x to avoid deprecation warnings
  * Support for Balance Board calibration
  Remove wiiuse-soname.patch
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Jan 30 2023 Carsten Ziepke <kieltux@gmail.com>
- Add BuildRequires pkgconfig and use pkgconfig for sdl, fix
  building for openSUSE Leap
* Sat Apr 10 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.15.5
  * Removed WCONST macro
  * Fixed the L2CAP channel setup on Linux, now we use only the
    interrupt/data channel (0x13) and not the control channel (0x11)
  * Fixed the RVL-CNT-01-TR (gen 2) Wiimote.
  * Added: Callback API with constant-size wiimote_callback_data_t.
  * Initial MotionPlus support.
  * Properly disable rumbling when told to.
  * Additional internal function wiiuse_millisleep() to reduce the
    number of ifdefs scattered through the code.
  * Provide endianness-conversion and buffer/unbuffer functions,
    rather than a jumble of function-style macros and raw type punning.
* Fri May 15 2015 tchvatal@suse.com
- Version bump once more to git snapshot 0.14_p20150515:
  * Various fixes to match up state from supertuxkart
  * Should be compatible with 0.12 and 0.14 still
  * Mostly small fixes all around for Linux
- Refreshed patch:
  * wiiuse-soname.patch
* Fri May 15 2015 tchvatal@suse.com
- Version bump to 0.14, various changes, see CHANGELOG
- Remove obsoleted patches:
  * wiiuse-0.12-arraysubscript.patch
  * wiiuse-0.12-destdir.patch
  * wiiuse-0.12-example-libs.patch
  * wiiuse-0.12-example-sdl.patch
- Add patch to generate properly soname:
  * wiiuse-soname.patch
* Mon Mar 18 2013 joop.boonen@opensuse.org
- Cleaned the spec file up
* Thu Apr 14 2011 Rene.vanPaassen@gmail.com
- initial version, 0.12
